# ece4078
Support files for ECE4078 Practicals

Please install manually with
```
python3 setup.py install 
```
Or if you want to install it to your current user only
```
python3 setup.py install --user
```

This repo is also hosted on PyPi, however, it will not always get the newest fix :P, and I did not put all of the dependencies in the `install_requires` tag so use it at your own risk!
```
python3 -m pip install ece4078
```
